@@ -17,8 +17,11 @@
 #
 set -e
 
+# Packages needed for puppeteer:
+apt update
+apt install -y chromium
+
 cd /app/superset-frontend
-npm install -g npm@7
 npm install -f --no-optional --global webpack webpack-cli
 npm install -f --no-optional
 
