@@ -18,6 +18,7 @@
  */
 
 import React from 'react';
+import { t } from '@superset-ui/core';
 import { SupersetTheme } from '../../style';
 import { FallbackPropsWithDimension } from './SuperChart';
 
@@ -41,13 +42,13 @@ export default function FallbackComponent({
     >
       <div>
         <div>
-          <b>Oops! An error occurred!</b>
+          <b>{t('Oops! An error occurred!')}</b>
         </div>
         <code>{error ? error.toString() : 'Unknown Error'}</code>
       </div>
       {componentStack && (
         <div>
-          <b>Stack Trace:</b>
+          <b>{t('Stack Trace:')}</b>
           <code>
             {componentStack.split('\n').map((row: string) => (
               <div key={row}>{row}</div>
