@@ -17,9 +17,12 @@
  * under the License.
  */
 
-import austria from './countries/austria.geojson';
+import afghanistan from './countries/afghanistan.geojson';
+import albania from './countries/albania.geojson';
+import algeria from './countries/algeria.geojson';
 import argentina from './countries/argentina.geojson';
 import australia from './countries/australia.geojson';
+import austria from './countries/austria.geojson';
 import belgium from './countries/belgium.geojson';
 import bolivia from './countries/bolivia.geojson';
 import brazil from './countries/brazil.geojson';
@@ -29,14 +32,14 @@ import canada from './countries/canada.geojson';
 import chile from './countries/chile.geojson';
 import china from './countries/china.geojson';
 import colombia from './countries/colombia.geojson';
-import costa_rica from './countries/costa rica.geojson';
+import costa_rica from './countries/costa_rica.geojson';
 import cuba from './countries/cuba.geojson';
 import cyprus from './countries/cyprus.geojson';
 import denmark from './countries/denmark.geojson';
-import dominican_republic from './countries/dominican republic.geojson';
+import dominican_republic from './countries/dominican_republic.geojson';
 import ecuador from './countries/ecuador.geojson';
 import egypt from './countries/egypt.geojson';
-import el_salvador from './countries/el salvador.geojson';
+import el_salvador from './countries/el_salvador.geojson';
 import estonia from './countries/estonia.geojson';
 import ethiopia from './countries/ethiopia.geojson';
 import france from './countries/france.geojson';
@@ -62,35 +65,35 @@ import kyrgyzstan from './countries/kyrgyzstan.geojson';
 import latvia from './countries/latvia.geojson';
 import liechtenstein from './countries/liechtenstein.geojson';
 import lithuania from './countries/lithuania.geojson';
-import nigeria from './countries/nigeria.geojson';
-import norway from './countries/norway.geojson';
 import malaysia from './countries/malaysia.geojson';
 import mexico from './countries/mexico.geojson';
 import morocco from './countries/morocco.geojson';
 import myanmar from './countries/myanmar.geojson';
 import netherlands from './countries/netherlands.geojson';
 import nicaragua from './countries/nicaragua.geojson';
+import nigeria from './countries/nigeria.geojson';
+import norway from './countries/norway.geojson';
 import oman from './countries/oman.geojson';
 import pakistan from './countries/pakistan.geojson';
 import panama from './countries/panama.geojson';
-import papua_new_guinea from './countries/papua new guinea.geojson';
+import papua_new_guinea from './countries/papua_new_guinea.geojson';
 import paraguay from './countries/paraguay.geojson';
-import philippines from './countries/philippines.geojson';
 import peru from './countries/peru.geojson';
-import poland from './countries/poland.geojson';
+import philippines from './countries/philippines.geojson';
 import portugal from './countries/portugal.geojson';
-import puerto_rico from './countries/puerto rico.geojson';
+import poland from './countries/poland.geojson';
+import puerto_rico from './countries/puerto_rico.geojson';
 import qatar from './countries/qatar.geojson';
 import russia from './countries/russia.geojson';
 import rwanda from './countries/rwanda.geojson';
-import saint_barthelemy from './countries/saint barthelemy.geojson';
-import saint_martin from './countries/saint martin.geojson';
+import saint_barthelemy from './countries/saint_barthelemy.geojson';
+import saint_martin from './countries/saint_martin.geojson';
 import saudi_arabia from './countries/saudi_arabia.geojson';
 import singapore from './countries/singapore.geojson';
 import slovenia from './countries/slovenia.geojson';
-import sweden from './countries/sweden.geojson';
 import spain from './countries/spain.geojson';
-import srilanka from './countries/srilanka.geojson';
+import sri_lanka from './countries/sri_lanka.geojson';
+import sweden from './countries/sweden.geojson';
 import switzerland from './countries/switzerland.geojson';
 import syria from './countries/syria.geojson';
 import tajikistan from './countries/tajikistan.geojson';
@@ -99,21 +102,24 @@ import thailand from './countries/thailand.geojson';
 import timorleste from './countries/timorleste.geojson';
 import turkey from './countries/turkey.geojson';
 import turkmenistan from './countries/turkmenistan.geojson';
-import united_arab_emirates from './countries/united_arab_emirates.geojson';
 import uganda from './countries/uganda.geojson';
 import uk from './countries/uk.geojson';
 import ukraine from './countries/ukraine.geojson';
+import united_arab_emirates from './countries/united_arab_emirates.geojson';
 import uruguay from './countries/uruguay.geojson';
 import usa from './countries/usa.geojson';
 import uzbekistan from './countries/uzbekistan.geojson';
-import zambia from './countries/zambia.geojson';
 import venezuela from './countries/venezuela.geojson';
 import vietnam from './countries/vietnam.geojson';
+import zambia from './countries/zambia.geojson';
 
 export const countries = {
-  austria,
+  afghanistan,
+  albania,
+  algeria,
   argentina,
   australia,
+  austria,
   belgium,
   bolivia,
   brazil,
@@ -169,10 +175,10 @@ export const countries = {
   panama,
   papua_new_guinea,
   paraguay,
-  philippines,
   peru,
-  poland,
+  philippines,
   portugal,
+  poland,
   puerto_rico,
   qatar,
   russia,
@@ -183,7 +189,7 @@ export const countries = {
   singapore,
   slovenia,
   spain,
-  srilanka,
+  sri_lanka,
   sweden,
   switzerland,
   syria,
@@ -193,16 +199,16 @@ export const countries = {
   timorleste,
   turkey,
   turkmenistan,
-  united_arab_emirates,
   uganda,
   uk,
   ukraine,
+  united_arab_emirates,
   uruguay,
   usa,
   uzbekistan,
-  zambia,
   venezuela,
   vietnam,
+  zambia,
 };
 
 export const countryOptions = Object.keys(countries).map(x => {
@@ -215,7 +221,13 @@ export const countryOptions = Object.keys(countries).map(x => {
   if (x === 'france_regions') {
     return [x, 'France (regions)'];
   }
-  return [x, x[0].toUpperCase() + x.slice(1)];
+  return [
+    x,
+    x
+      .split('_')
+      .map(e => e[0].toUpperCase() + e.slice(1))
+      .join(' '),
+  ];
 });
 
 export default countries;
