@@ -16,14 +16,13 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import { hasGenericChartAxes, smartDateFormatter, t } from '@superset-ui/core';
+import { smartDateFormatter, t } from '@superset-ui/core';
 import {
   ControlPanelConfig,
   ControlSubSectionHeader,
   D3_FORMAT_DOCS,
   D3_TIME_FORMAT_OPTIONS,
   getStandardizedControls,
-  sections,
   temporalColumnMixin,
 } from '@superset-ui/chart-controls';
 import React from 'react';
@@ -31,13 +30,12 @@ import { headerFontSize, subheaderFontSize } from '../sharedControls';
 
 const config: ControlPanelConfig = {
   controlPanelSections: [
-    sections.genericTime,
     {
       label: t('Query'),
       expanded: true,
       controlSetRows: [
-        [hasGenericChartAxes ? 'x_axis' : null],
-        [hasGenericChartAxes ? 'time_grain_sqla' : null],
+        ['x_axis'],
+        ['time_grain_sqla'],
         ['metric'],
         ['adhoc_filters'],
       ],
