@@ -21,9 +21,17 @@ import { EchartsProps } from '../types';
 import Echart from '../components/Echart';
 
 export default function EchartsGraph({
-  height,
-  width,
   echartOptions,
+  height,
+  refs,
+  width,
 }: EchartsProps) {
-  return <Echart height={height} width={width} echartOptions={echartOptions} />;
+  return (
+    <Echart
+      refs={refs}
+      height={height}
+      width={width}
+      echartOptions={echartOptions}
+    />
+  );
 }
