@@ -19,14 +19,13 @@
 import React, { useState, useEffect, useRef } from 'react';
 import type { IAceEditor } from 'react-ace/lib/types';
 import { useDispatch } from 'react-redux';
-import { css, styled, usePrevious, useTheme } from '@superset-ui/core';
-import { Global } from '@emotion/react';
+import { css, styled, usePrevious } from '@superset-ui/core';
 
-import { SQL_EDITOR_LEFTBAR_WIDTH } from 'src/SqlLab/constants';
 import { queryEditorSetSelectedText } from 'src/SqlLab/actions/sqlLab';
 import { FullSQLEditor as AceEditor } from 'src/components/AsyncAceEditor';
 import type { KeyboardShortcut } from 'src/SqlLab/components/KeyboardShortcutButton';
 import useQueryEditor from 'src/SqlLab/hooks/useQueryEditor';
+import type { CursorPosition } from 'src/SqlLab/types';
 import { useAnnotations } from './useAnnotations';
 import { useKeywords } from './useKeywords';
 
@@ -42,6 +41,7 @@ type AceEditorWrapperProps = {
   onBlur: (sql: string) => void;
   onChange: (sql: string) => void;
   queryEditorId: string;
+  onCursorPositionChange: (position: CursorPosition) => void;
   height: string;
   hotkeys: HotKey[];
 };
@@ -51,7 +51,19 @@ const StyledAceEditor = styled(AceEditor)`
     && {
       // double class is better than !important
       border: 1px solid ${theme.colors.grayscale.light2};
-      font-feature-settings: 'liga' off, 'calt' off;
+      font-feature-settings:
+        'liga' off,
+        'calt' off;
+
+      &.ace_autocomplete {
+        // Use !important because Ace Editor applies extra CSS at the last second
+        // when opening the autocomplete.
+        width: ${theme.gridUnit * 130}px !important;
+      }
+
+      .ace_scroller {
+        background-color: ${theme.colors.grayscale.light4};
+      }
     }
   `}
 `;
@@ -61,6 +73,7 @@ const AceEditorWrapper = ({
   onBlur = () => {},
   onChange = () => {},
   queryEditorId,
+  onCursorPositionChange,
   height,
   hotkeys,
 }: AceEditorWrapperProps) => {
@@ -71,10 +84,11 @@ const AceEditorWrapper = ({
     'sql',
     'schema',
     'templateParams',
+    'cursorPosition',
   ]);
 
   const currentSql = queryEditor.sql ?? '';
-
+  const cursorPosition = queryEditor.cursorPosition ?? { row: 0, column: 0 };
   const [sql, setSql] = useState(currentSql);
 
   // The editor changeSelection is called multiple times in a row,
@@ -135,6 +149,15 @@ const AceEditorWrapper = ({
 
       currentSelectionCache.current = selectedText;
     });
+    editor.selection.on('changeCursor', () => {
+      const cursor = editor.getCursorPosition();
+      onCursorPositionChange(cursor);
+    });
+
+    const { row, column } = cursorPosition;
+    editor.moveCursorToPosition({ row, column });
+    editor.focus();
+    editor.scrollToLine(row, true, true);
   };
 
   const onChangeText = (text: string) => {
@@ -159,44 +182,20 @@ const AceEditorWrapper = ({
     },
     !autocomplete,
   );
-  const theme = useTheme();
 
   return (
-    <>
-      <Global
-        styles={css`
-          .ace_text-layer {
-            width: 100% !important;
-          }
-
-          .ace_autocomplete {
-            // Use !important because Ace Editor applies extra CSS at the last second
-            // when opening the autocomplete.
-            width: ${theme.gridUnit * 130}px !important;
-          }
-
-          .ace_tooltip {
-            max-width: ${SQL_EDITOR_LEFTBAR_WIDTH}px;
-          }
-
-          .ace_scroller {
-            background-color: ${theme.colors.grayscale.light4};
-          }
-        `}
-      />
-      <StyledAceEditor
-        keywords={keywords}
-        onLoad={onEditorLoad}
-        onBlur={onBlurSql}
-        height={height}
-        onChange={onChangeText}
-        width="100%"
-        editorProps={{ $blockScrolling: true }}
-        enableLiveAutocompletion={autocomplete}
-        value={sql}
-        annotations={annotations}
-      />
-    </>
+    <StyledAceEditor
+      keywords={keywords}
+      onLoad={onEditorLoad}
+      onBlur={onBlurSql}
+      height={height}
+      onChange={onChangeText}
+      width="100%"
+      editorProps={{ $blockScrolling: true }}
+      enableLiveAutocompletion={autocomplete}
+      value={sql}
+      annotations={annotations}
+    />
   );
 };
 
