@@ -26,8 +26,9 @@ import { ErrorLevel, ErrorSource, ErrorTypeEnum } from './types';
 jest.mock(
   'src/components/Icons/Icon',
   () =>
-    ({ fileName }: { fileName: string }) =>
-      <span role="img" aria-label={fileName.replace('_', '-')} />,
+    ({ fileName }: { fileName: string }) => (
+      <span role="img" aria-label={fileName.replace('_', '-')} />
+    ),
 );
 
 const mockedProps = {
@@ -55,14 +56,7 @@ const mockedProps = {
 };
 
 test('should render', () => {
-  const nullExtraProps = {
-    ...mockedProps,
-    error: {
-      ...mockedProps.error,
-      extra: null,
-    },
-  };
-  const { container } = render(<DatabaseErrorMessage {...nullExtraProps} />);
+  const { container } = render(<DatabaseErrorMessage {...mockedProps} />);
   expect(container).toBeInTheDocument();
 });
 
