@@ -91,32 +91,32 @@ export interface InternalFilter extends FilterValue {
 }
 
 export enum FilterOperator {
-  startsWith = 'sw',
-  endsWith = 'ew',
-  contains = 'ct',
-  equals = 'eq',
-  notStartsWith = 'nsw',
-  notEndsWith = 'new',
-  notContains = 'nct',
-  notEquals = 'neq',
-  greaterThan = 'gt',
-  lessThan = 'lt',
-  relationManyMany = 'rel_m_m',
-  relationOneMany = 'rel_o_m',
-  titleOrSlug = 'title_or_slug',
-  nameOrDescription = 'name_or_description',
-  allText = 'all_text',
-  chartAllText = 'chart_all_text',
-  datasetIsNullOrEmpty = 'dataset_is_null_or_empty',
-  between = 'between',
-  dashboardIsFav = 'dashboard_is_favorite',
-  chartIsFav = 'chart_is_favorite',
-  chartIsCertified = 'chart_is_certified',
-  dashboardIsCertified = 'dashboard_is_certified',
-  datasetIsCertified = 'dataset_is_certified',
-  dashboardHasCreatedBy = 'dashboard_has_created_by',
-  chartHasCreatedBy = 'chart_has_created_by',
-  dashboardTags = 'dashboard_tags',
-  chartTags = 'chart_tags',
-  savedQueryTags = 'saved_query_tags',
+  StartsWith = 'sw',
+  EndsWith = 'ew',
+  Contains = 'ct',
+  Equals = 'eq',
+  NotStartsWith = 'nsw',
+  NotEndsWith = 'new',
+  NotContains = 'nct',
+  NotEquals = 'neq',
+  GreaterThan = 'gt',
+  LessThan = 'lt',
+  RelationManyMany = 'rel_m_m',
+  RelationOneMany = 'rel_o_m',
+  TitleOrSlug = 'title_or_slug',
+  NameOrDescription = 'name_or_description',
+  AllText = 'all_text',
+  ChartAllText = 'chart_all_text',
+  DatasetIsNullOrEmpty = 'dataset_is_null_or_empty',
+  Between = 'between',
+  DashboardIsFav = 'dashboard_is_favorite',
+  ChartIsFav = 'chart_is_favorite',
+  ChartIsCertified = 'chart_is_certified',
+  DashboardIsCertified = 'dashboard_is_certified',
+  DatasetIsCertified = 'dataset_is_certified',
+  DashboardHasCreatedBy = 'dashboard_has_created_by',
+  ChartHasCreatedBy = 'chart_has_created_by',
+  DashboardTags = 'dashboard_tags',
+  ChartTags = 'chart_tags',
+  SavedQueryTags = 'saved_query_tags',
 }
