@@ -18,7 +18,6 @@
  */
 import React from 'react';
 import { action } from '@storybook/addon-actions';
-import { boolean, text } from '@storybook/addon-knobs';
 import { AntdDropdown } from 'src/components';
 import { Menu } from 'src/components/Menu';
 import Icons from 'src/components/Icons';
@@ -28,21 +27,39 @@ import ListViewCard from '.';
 export default {
   title: 'ListViewCard',
   component: ListViewCard,
+  argTypes: {
+    loading: { control: 'boolean', defaultValue: false },
+    imgURL: {
+      control: 'text',
+      defaultValue:
+        'https://images.unsplash.com/photo-1658163724548-29ef00812a54?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=2670&q=80',
+    },
+    imgFallbackURL: {
+      control: 'text',
+      defaultValue:
+        'https://images.unsplash.com/photo-1658208193219-e859d9771912?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=2670&q=80',
+    },
+    isStarred: { control: 'boolean', defaultValue: false },
+  },
 };
 
-export const SupersetListViewCard = () => (
+export const SupersetListViewCard = ({
+  loading,
+  imgURL,
+  imgFallbackURL,
+  isStarred,
+}: {
+  loading: boolean;
+  imgURL: string;
+  imgFallbackURL: string;
+  isStarred: boolean;
+}) => (
   <ListViewCard
     title="Superset Card Title"
-    loading={boolean('loading', false)}
+    loading={loading}
     url="/superset/dashboard/births/"
-    imgURL={text(
-      'imgURL',
-      'https://images.unsplash.com/photo-1658163724548-29ef00812a54?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=2670&q=80',
-    )}
-    imgFallbackURL={text(
-      'imgURL',
-      'https://images.unsplash.com/photo-1658208193219-e859d9771912?ixlib=rb-1.2.1&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=2670&q=80',
-    )}
+    imgURL={imgURL}
+    imgFallbackURL={imgFallbackURL}
     description="Lorem ipsum dolor sit amet, consectetur adipiscing elit..."
     coverLeft="Left Section"
     coverRight="Right Section"
@@ -52,7 +69,7 @@ export const SupersetListViewCard = () => (
           itemId={0}
           fetchFaveStar={action('fetchFaveStar')}
           saveFaveStar={action('saveFaveStar')}
-          isStarred={boolean('isStarred', false)}
+          isStarred={isStarred}
         />
         <AntdDropdown
           overlay={
