@@ -218,8 +218,8 @@ test('sort the options by label if no sort comparator is provided', async () =>
 
 test('sort the options using a custom sort comparator', async () => {
   const sortComparator = (
-    option1: typeof OPTIONS[0],
-    option2: typeof OPTIONS[0],
+    option1: (typeof OPTIONS)[0],
+    option2: (typeof OPTIONS)[0],
   ) => option1.gender.localeCompare(option2.gender);
   render(<AsyncSelect {...defaultProps} sortComparator={sortComparator} />);
   await open();
@@ -384,14 +384,12 @@ test('removes duplicated values', async () => {
     },
   });
   fireEvent(input, paste);
-  await waitFor(async () => {
-    const values = await findAllSelectValues();
-    expect(values.length).toBe(4);
-    expect(values[0]).toHaveTextContent('a');
-    expect(values[1]).toHaveTextContent('b');
-    expect(values[2]).toHaveTextContent('c');
-    expect(values[3]).toHaveTextContent('d');
-  });
+  const values = await findAllSelectValues();
+  expect(values.length).toBe(4);
+  expect(values[0]).toHaveTextContent('a');
+  expect(values[1]).toHaveTextContent('b');
+  expect(values[2]).toHaveTextContent('c');
+  expect(values[3]).toHaveTextContent('d');
 });
 
 test('renders a custom label', async () => {
@@ -881,7 +879,7 @@ test('fires onChange when pasting a selection', async () => {
     },
   });
   fireEvent(input, paste);
-  await waitFor(() => expect(onChange).toHaveBeenCalledTimes(1));
+  expect(onChange).toHaveBeenCalledTimes(1);
 });
 
 test('does not duplicate options when using numeric values', async () => {
@@ -928,14 +926,7 @@ test('pasting an existing option does not duplicate it in multiple mode', async
     ],
     totalCount: 3,
   }));
-  render(
-    <AsyncSelect
-      {...defaultProps}
-      options={options}
-      mode="multiple"
-      allowNewOptions
-    />,
-  );
+  render(<AsyncSelect {...defaultProps} options={options} mode="multiple" />);
   await open();
   const input = getElementByClassName('.ant-select-selection-search-input');
   const paste = createEvent.paste(input, {
@@ -944,49 +935,8 @@ test('pasting an existing option does not duplicate it in multiple mode', async
     },
   });
   fireEvent(input, paste);
-  await waitFor(async () =>
-    // Only Peter should be added
-    expect(await findAllSelectOptions()).toHaveLength(4),
-  );
-});
-
-test('pasting an non-existent option should not add it if allowNewOptions is false', async () => {
-  render(
-    <AsyncSelect
-      {...defaultProps}
-      allowNewOptions={false}
-      options={async () => ({ data: [], totalCount: 0 })}
-    />,
-  );
-  await open();
-  const input = getElementByClassName('.ant-select-selection-search-input');
-  const paste = createEvent.paste(input, {
-    clipboardData: {
-      getData: () => 'John',
-    },
-  });
-  await waitFor(() => fireEvent(input, paste));
-  expect(await findAllSelectOptions()).toHaveLength(0);
-});
-
-test('onChange is called with the value property when pasting an option that was not loaded yet', async () => {
-  const onChange = jest.fn();
-  render(<AsyncSelect {...defaultProps} onChange={onChange} />);
-  await open();
-  const input = getElementByClassName('.ant-select-selection-search-input');
-  const lastOption = OPTIONS[OPTIONS.length - 1];
-  const paste = createEvent.paste(input, {
-    clipboardData: {
-      getData: () => lastOption.label,
-    },
-  });
-  fireEvent(input, paste);
-  await waitFor(() =>
-    expect(onChange).toHaveBeenCalledWith(
-      expect.objectContaining({ value: lastOption.value }),
-      expect.anything(),
-    ),
-  );
+  // Only Peter should be added
+  expect(await findAllSelectOptions()).toHaveLength(4);
 });
 
 test('does not fire onChange if the same value is selected in single mode', async () => {
