@@ -88,8 +88,8 @@ const TIMEZONE_OPTIONS = TIMEZONES.map(zone => ({
 }));
 
 const TIMEZONE_OPTIONS_SORT_COMPARATOR = (
-  a: typeof TIMEZONE_OPTIONS[number],
-  b: typeof TIMEZONE_OPTIONS[number],
+  a: (typeof TIMEZONE_OPTIONS)[number],
+  b: (typeof TIMEZONE_OPTIONS)[number],
 ) =>
   moment.tz(currentDate, a.timezoneName).utcOffset() -
   moment.tz(currentDate, b.timezoneName).utcOffset();
