@@ -40,9 +40,6 @@ import SliceHeader from '../SliceHeader';
 import MissingChart from '../MissingChart';
 import { slicePropShape, chartPropShape } from '../../util/propShapes';
 
-import { isFilterBox } from '../../util/activeDashboardFilters';
-import getFilterValuesByFilterId from '../../util/getFilterValuesByFilterId';
-
 const propTypes = {
   id: PropTypes.number.isRequired,
   componentId: PropTypes.string.isRequired,
@@ -100,7 +97,6 @@ const SHOULD_UPDATE_ON_PROP_CHANGES = Object.keys(propTypes).filter(
   prop =>
     prop !== 'width' && prop !== 'height' && prop !== 'isComponentVisible',
 );
-const OVERFLOWABLE_VIZ_TYPES = new Set(['filter_box']);
 const DEFAULT_HEADER_HEIGHT = 22;
 
 const ChartWrapper = styled.div`
@@ -423,13 +419,7 @@ class Chart extends React.Component {
     const cachedDttm =
       // eslint-disable-next-line camelcase
       queriesResponse?.map(({ cached_dttm }) => cached_dttm) || [];
-    const isOverflowable = OVERFLOWABLE_VIZ_TYPES.has(slice.viz_type);
-    const initialValues = isFilterBox(id)
-      ? getFilterValuesByFilterId({
-          activeFilters: filters,
-          filterId: id,
-        })
-      : {};
+    const initialValues = {};
 
     return (
       <SliceContainer
@@ -491,12 +481,7 @@ class Chart extends React.Component {
           />
         )}
 
-        <ChartWrapper
-          className={cx(
-            'dashboard-chart',
-            isOverflowable && 'dashboard-chart--overflowable',
-          )}
-        >
+        <ChartWrapper className={cx('dashboard-chart')}>
           {isLoading && (
             <ChartOverlay
               style={{
