@@ -17,13 +17,11 @@
  * under the License.
  */
 import React from 'react';
-import { shallow } from 'enzyme';
+import { render } from 'spec/helpers/testing-library';
 
 import HoverMenu from 'src/dashboard/components/menu/HoverMenu';
 
-describe('HoverMenu', () => {
-  it('should render a div.hover-menu', () => {
-    const wrapper = shallow(<HoverMenu />);
-    expect(wrapper.find('.hover-menu')).toExist();
-  });
+test('should render a div.hover-menu', () => {
+  const { container } = render(<HoverMenu />);
+  expect(container.querySelector('.hover-menu')).toBeInTheDocument();
 });
