@@ -22,13 +22,14 @@ import Icons from 'src/components/Icons';
 import { FilterRemoval } from './types';
 import DraggableFilter from './DraggableFilter';
 
-const FilterTitle = styled.div`
+export const FilterTitle = styled.div`
   ${({ theme }) => `
       display: flex;
       align-items: center;
       padding: ${theme.gridUnit * 2}px;
       width: 100%;
       border-radius: ${theme.borderRadius}px;
+      cursor: pointer;
       &.active {
         color: ${theme.colors.grayscale.dark1};
         border-radius: ${theme.borderRadius}px;
@@ -111,7 +112,13 @@ const FilterTitleContainer = forwardRef<HTMLDivElement, Props>(
           className={classNames.join(' ')}
         >
           <div css={{ display: 'flex', width: '100%' }}>
-            <div css={{ alignItems: 'center', display: 'flex' }}>
+            <div
+              css={{
+                alignItems: 'center',
+                display: 'flex',
+                wordBreak: 'break-all',
+              }}
+            >
               {isRemoved ? t('(Removed)') : getFilterTitle(id)}
             </div>
             {!removedFilters[id] && isErrored && (
