@@ -96,8 +96,8 @@ export function ColumnSelect({
       }).then(
         ({ json: { result } }) => {
           const lookupValue = Array.isArray(value) ? value : [value];
-          const valueExists = result.columns.some((column: Column) =>
-            lookupValue?.includes(column.column_name),
+          const valueExists = result.columns.some(
+            (column: Column) => lookupValue?.includes(column.column_name),
           );
           if (!valueExists) {
             resetColumnField();
