@@ -95,12 +95,10 @@ function mapStateToProps(
     supersetCanExplore: !!dashboardInfo.superset_can_explore,
     supersetCanShare: !!dashboardInfo.superset_can_share,
     supersetCanCSV: !!dashboardInfo.superset_can_csv,
-    sliceCanEdit: !!dashboardInfo.slice_can_edit,
     ownState: dataMask[id]?.ownState,
     filterState: dataMask[id]?.filterState,
     maxRows: common.conf.SQL_MAX_ROW,
     setControlValue,
-    filterboxMigrationState: dashboardState.filterboxMigrationState,
     datasetsStatus,
     emitCrossFilters: !!dashboardInfo.crossFiltersEnabled,
   };
