@@ -391,4 +391,57 @@ describe('getSlicePayload', () => {
       formDataFromSlice.adhoc_filters,
     );
   });
+
+  test('should return the correct payload when formDataWithNativeFilters has a filter with isExtra set to true in mixed chart', () => {
+    const formDataFromSliceWithAdhocFilterB = {
+      ...formDataFromSlice,
+      adhoc_filters_b: [
+        {
+          clause: 'WHERE',
+          subject: 'year',
+          operator: 'TEMPORAL_RANGE',
+          comparator: 'No filter',
+          expressionType: 'SIMPLE',
+        },
+      ],
+    };
+    const formDataWithAdhocFiltersWithExtra = {
+      ...formDataWithNativeFilters,
+      viz_type: 'mixed_timeseries',
+      adhoc_filters: [
+        {
+          clause: 'WHERE',
+          subject: 'year',
+          operator: 'TEMPORAL_RANGE',
+          comparator: 'No filter',
+          expressionType: 'SIMPLE',
+          isExtra: true,
+        },
+      ],
+      adhoc_filters_b: [
+        {
+          clause: 'WHERE',
+          subject: 'year',
+          operator: 'TEMPORAL_RANGE',
+          comparator: 'No filter',
+          expressionType: 'SIMPLE',
+          isExtra: true,
+        },
+      ],
+    };
+    const result = getSlicePayload(
+      sliceName,
+      formDataWithAdhocFiltersWithExtra,
+      dashboards,
+      owners,
+      formDataFromSliceWithAdhocFilterB,
+    );
+
+    expect(JSON.parse(result.params).adhoc_filters).toEqual(
+      formDataFromSliceWithAdhocFilterB.adhoc_filters,
+    );
+    expect(JSON.parse(result.params).adhoc_filters_b).toEqual(
+      formDataFromSliceWithAdhocFilterB.adhoc_filters_b,
+    );
+  });
 });
