@@ -17,6 +17,7 @@
  * under the License.
  */
 import React from 'react';
+import userEvent from '@testing-library/user-event';
 import { render, screen } from 'spec/helpers/testing-library';
 import {
   DatasourceType,
@@ -97,10 +98,50 @@ describe('ControlPanelsContainer', () => {
     } as ControlPanelsContainerProps;
   }
 
-  it('renders ControlPanelSections', () => {
-    render(<ControlPanelsContainer {...getDefaultProps()} />);
+  test('renders ControlPanelSections', async () => {
+    render(<ControlPanelsContainer {...getDefaultProps()} />, {
+      useRedux: true,
+    });
     expect(
-      screen.getAllByTestId('collapsible-control-panel-header'),
+      await screen.findAllByTestId('collapsible-control-panel-header'),
     ).toHaveLength(4);
+    expect(screen.getByRole('tab', { name: /customize/i })).toBeInTheDocument();
+    userEvent.click(screen.getByRole('tab', { name: /customize/i }));
+    expect(
+      await screen.findAllByTestId('collapsible-control-panel-header'),
+    ).toHaveLength(5);
+  });
+
+  test('renders ControlPanelSections no Customize Tab', async () => {
+    getChartControlPanelRegistry().registerValue('table', {
+      controlPanelSections: [
+        {
+          label: t('GROUP BY'),
+          description: t(
+            'Use this section if you want a query that aggregates',
+          ),
+          expanded: true,
+          controlSetRows: [
+            ['groupby'],
+            ['metrics'],
+            ['percent_metrics'],
+            ['timeseries_limit_metric', 'row_limit'],
+            ['include_time', 'order_desc'],
+          ],
+        },
+        {
+          label: t('Options'),
+          expanded: true,
+          controlSetRows: [],
+        },
+      ],
+    });
+    render(<ControlPanelsContainer {...getDefaultProps()} />, {
+      useRedux: true,
+    });
+    expect(screen.queryByText(/customize/i)).not.toBeInTheDocument();
+    expect(
+      await screen.findAllByTestId('collapsible-control-panel-header'),
+    ).toHaveLength(2);
   });
 });
