@@ -22,7 +22,7 @@ import {
   OPERATOR_ENUM_TO_OPERATOR_TYPE,
 } from 'src/explore/constants';
 import { translateToSql } from '../utils/translateToSQL';
-import { CLAUSES, EXPRESSION_TYPES } from '../types';
+import { Clauses, ExpressionTypes } from '../types';
 
 const CUSTOM_OPERATIONS = [...CUSTOM_OPERATORS].map(
   op => OPERATOR_ENUM_TO_OPERATOR_TYPE[op].operation,
@@ -30,29 +30,28 @@ const CUSTOM_OPERATIONS = [...CUSTOM_OPERATORS].map(
 
 export default class AdhocFilter {
   constructor(adhocFilter) {
-    this.expressionType = adhocFilter.expressionType || EXPRESSION_TYPES.SIMPLE;
-    if (this.expressionType === EXPRESSION_TYPES.SIMPLE) {
+    this.expressionType = adhocFilter.expressionType || ExpressionTypes.Simple;
+    if (this.expressionType === ExpressionTypes.Simple) {
       this.subject = adhocFilter.subject;
       this.operator = adhocFilter.operator?.toUpperCase();
       this.operatorId = adhocFilter.operatorId;
       this.comparator = adhocFilter.comparator;
       if (
-        [Operators.IS_TRUE, Operators.IS_FALSE].indexOf(
-          adhocFilter.operatorId,
-        ) >= 0
+        [Operators.IsTrue, Operators.IsFalse].indexOf(adhocFilter.operatorId) >=
+        0
       ) {
-        this.comparator = adhocFilter.operatorId === Operators.IS_TRUE;
+        this.comparator = adhocFilter.operatorId === Operators.IsTrue;
       }
       if (
-        [Operators.IS_NULL, Operators.IS_NOT_NULL].indexOf(
+        [Operators.IsNull, Operators.IsNotNull].indexOf(
           adhocFilter.operatorId,
         ) >= 0
       ) {
         this.comparator = null;
       }
-      this.clause = adhocFilter.clause || CLAUSES.WHERE;
+      this.clause = adhocFilter.clause || Clauses.Where;
       this.sqlExpression = null;
-    } else if (this.expressionType === EXPRESSION_TYPES.SQL) {
+    } else if (this.expressionType === ExpressionTypes.Sql) {
       this.sqlExpression =
         typeof adhocFilter.sqlExpression === 'string'
           ? adhocFilter.sqlExpression
@@ -103,13 +102,13 @@ export default class AdhocFilter {
   }
 
   isValid() {
-    const nullCheckOperators = [Operators.IS_NOT_NULL, Operators.IS_NULL].map(
+    const nullCheckOperators = [Operators.IsNotNull, Operators.IsNull].map(
       op => OPERATOR_ENUM_TO_OPERATOR_TYPE[op].operation,
     );
-    const truthCheckOperators = [Operators.IS_TRUE, Operators.IS_FALSE].map(
+    const truthCheckOperators = [Operators.IsTrue, Operators.IsFalse].map(
       op => OPERATOR_ENUM_TO_OPERATOR_TYPE[op].operation,
     );
-    if (this.expressionType === EXPRESSION_TYPES.SIMPLE) {
+    if (this.expressionType === ExpressionTypes.Simple) {
       if (nullCheckOperators.indexOf(this.operator) >= 0) {
         return !!(this.operator && this.subject);
       }
@@ -127,7 +126,7 @@ export default class AdhocFilter {
           return true;
         }
       }
-    } else if (this.expressionType === EXPRESSION_TYPES.SQL) {
+    } else if (this.expressionType === ExpressionTypes.Sql) {
       return !!(this.sqlExpression && this.clause);
     }
     return false;
