@@ -21,7 +21,7 @@ import { NO_TIME_RANGE } from '@superset-ui/core';
 import { fetchTimeRange } from 'src/explore/components/controls/DateFilterControl';
 import { Operators } from 'src/explore/constants';
 import AdhocFilter from '../AdhocFilter';
-import { EXPRESSION_TYPES } from '../types';
+import { ExpressionTypes } from '../types';
 
 interface Results {
   actualTimeRange?: string;
@@ -33,13 +33,13 @@ export const useGetTimeRangeLabel = (adhocFilter: AdhocFilter): Results => {
 
   useEffect(() => {
     if (
-      adhocFilter.operator !== Operators.TEMPORAL_RANGE ||
-      adhocFilter.expressionType !== EXPRESSION_TYPES.SIMPLE
+      adhocFilter.operator !== Operators.TemporalRange ||
+      adhocFilter.expressionType !== ExpressionTypes.Simple
     ) {
       setActualTimeRange({});
     }
     if (
-      adhocFilter.operator === Operators.TEMPORAL_RANGE &&
+      adhocFilter.operator === Operators.TemporalRange &&
       adhocFilter.comparator === NO_TIME_RANGE
     ) {
       setActualTimeRange({
@@ -49,8 +49,8 @@ export const useGetTimeRangeLabel = (adhocFilter: AdhocFilter): Results => {
     }
 
     if (
-      adhocFilter.operator === Operators.TEMPORAL_RANGE &&
-      adhocFilter.expressionType === EXPRESSION_TYPES.SIMPLE &&
+      adhocFilter.operator === Operators.TemporalRange &&
+      adhocFilter.expressionType === ExpressionTypes.Simple &&
       adhocFilter.comparator !== NO_TIME_RANGE &&
       actualTimeRange.title !== adhocFilter.comparator
     ) {
