@@ -18,7 +18,7 @@
  */
 
 import Owner from 'src/types/Owner';
-import { NOTIFICATION_FORMATS } from 'src/features/reports/types';
+import { NotificationFormats } from 'src/features/reports/types';
 
 type user = {
   id: number;
@@ -85,7 +85,7 @@ export type AlertObject = {
   sql?: string;
   timezone?: string;
   recipients?: Array<Recipient>;
-  report_format?: NOTIFICATION_FORMATS;
+  report_format?: NotificationFormats;
   type?: string;
   validator_config_json?: {
     op?: Operator;
@@ -123,3 +123,21 @@ export interface AlertsReportsConfig {
   ALERT_REPORTS_DEFAULT_RETENTION: number;
   ALERT_REPORTS_DEFAULT_CRON_VALUE: string;
 }
+
+export type SectionValidationObject = {
+  hasErrors: boolean;
+  errors: string[];
+  name: string;
+};
+
+export interface ValidationObject {
+  [key: string]: SectionValidationObject;
+}
+
+export enum Sections {
+  General = 'generalSection',
+  Content = 'contentSection',
+  Alert = 'alertConditionSection',
+  Schedule = 'scheduleSection',
+  Notification = 'notificationSection',
+}
