@@ -71,73 +71,74 @@ interface SavedQueryPreviewModalProps extends ToastProps {
   show: boolean;
 }
 
-const SavedQueryPreviewModal: FunctionComponent<SavedQueryPreviewModalProps> =
-  ({
-    fetchData,
-    onHide,
-    openInSqlLab,
-    queries,
-    savedQuery,
-    show,
-    addDangerToast,
-    addSuccessToast,
-  }) => {
-    const { handleKeyPress, handleDataChange, disablePrevious, disableNext } =
-      useQueryPreviewState<SavedQueryObject>({
-        queries,
-        currentQueryId: savedQuery.id,
-        fetchData,
-      });
+const SavedQueryPreviewModal: FunctionComponent<
+  SavedQueryPreviewModalProps
+> = ({
+  fetchData,
+  onHide,
+  openInSqlLab,
+  queries,
+  savedQuery,
+  show,
+  addDangerToast,
+  addSuccessToast,
+}) => {
+  const { handleKeyPress, handleDataChange, disablePrevious, disableNext } =
+    useQueryPreviewState<SavedQueryObject>({
+      queries,
+      currentQueryId: savedQuery.id,
+      fetchData,
+    });
 
-    return (
-      <div role="none" onKeyUp={handleKeyPress}>
-        <StyledModal
-          onHide={onHide}
-          show={show}
-          title={t('Query preview')}
-          footer={
-            <>
-              <Button
-                data-test="previous-saved-query"
-                key="previous-saved-query"
-                disabled={disablePrevious}
-                onClick={() => handleDataChange(true)}
-              >
-                {t('Previous')}
-              </Button>
-              <Button
-                data-test="next-saved-query"
-                key="next-saved-query"
-                disabled={disableNext}
-                onClick={() => handleDataChange(false)}
-              >
-                {t('Next')}
-              </Button>
-              <Button
-                data-test="open-in-sql-lab"
-                key="open-in-sql-lab"
-                buttonStyle="primary"
-                onClick={({ metaKey }) =>
-                  openInSqlLab(savedQuery.id, Boolean(metaKey))
-                }
-              >
-                {t('Open in SQL Lab')}
-              </Button>
-            </>
-          }
+  return (
+    <div role="none" onKeyUp={handleKeyPress}>
+      <StyledModal
+        onHide={onHide}
+        show={show}
+        title={t('Query preview')}
+        footer={
+          <>
+            <Button
+              data-test="previous-saved-query"
+              key="previous-saved-query"
+              disabled={disablePrevious}
+              onClick={() => handleDataChange(true)}
+            >
+              {t('Previous')}
+            </Button>
+            <Button
+              data-test="next-saved-query"
+              key="next-saved-query"
+              disabled={disableNext}
+              onClick={() => handleDataChange(false)}
+            >
+              {t('Next')}
+            </Button>
+            <Button
+              data-test="open-in-sql-lab"
+              key="open-in-sql-lab"
+              buttonStyle="primary"
+              onClick={({ metaKey }) =>
+                openInSqlLab(savedQuery.id, Boolean(metaKey))
+              }
+            >
+              {t('Open in SQL Lab')}
+            </Button>
+          </>
+        }
+      >
+        <QueryTitle>{t('Query name')}</QueryTitle>
+        <QueryLabel>{savedQuery.label}</QueryLabel>
+        <SyntaxHighlighterCopy
+          language="sql"
+          addDangerToast={addDangerToast}
+          addSuccessToast={addSuccessToast}
         >
-          <QueryTitle>{t('Query name')}</QueryTitle>
-          <QueryLabel>{savedQuery.label}</QueryLabel>
-          <SyntaxHighlighterCopy
-            language="sql"
-            addDangerToast={addDangerToast}
-            addSuccessToast={addSuccessToast}
-          >
-            {savedQuery.sql || ''}
-          </SyntaxHighlighterCopy>
-        </StyledModal>
-      </div>
-    );
-  };
+          {savedQuery.sql || ''}
+        </SyntaxHighlighterCopy>
+      </StyledModal>
+    </div>
+  );
+};
 
 export default withToasts(SavedQueryPreviewModal);
