@@ -82,14 +82,14 @@ const Wrapper = styled.div<{
     }
     & .ant-slider {
       margin-top: ${
-        orientation === FilterBarOrientation.HORIZONTAL ? 0 : theme.gridUnit
+        orientation === FilterBarOrientation.Horizontal ? 0 : theme.gridUnit
       }px;
       margin-bottom: ${
-        orientation === FilterBarOrientation.HORIZONTAL ? 0 : theme.gridUnit * 5
+        orientation === FilterBarOrientation.Horizontal ? 0 : theme.gridUnit * 5
       }px;
 
       ${
-        orientation === FilterBarOrientation.HORIZONTAL &&
+        orientation === FilterBarOrientation.Horizontal &&
         !isOverflowing &&
         `line-height: 1.2;`
       }
