@@ -25,6 +25,4 @@ export default interface Owner {
   first_name: string;
   id: number;
   last_name: string;
-  username: string;
-  email?: string;
 }
