@@ -123,10 +123,6 @@ const RowLevelSecurityList = lazy(
     ),
 );
 
-const Profile = lazy(
-  () => import(/* webpackChunkName: "Profile" */ 'src/pages/Profile'),
-);
-
 type Routes = {
   path: string;
   Component: React.ComponentType;
@@ -225,17 +221,13 @@ export const routes: Routes = [
     path: '/rowlevelsecurity/list',
     Component: RowLevelSecurityList,
   },
-  {
-    path: '/profile',
-    Component: Profile,
-  },
   {
     path: '/sqllab/',
     Component: SqlLab,
   },
 ];
 
-if (isFeatureEnabled(FeatureFlag.TAGGING_SYSTEM)) {
+if (isFeatureEnabled(FeatureFlag.TaggingSystem)) {
   routes.push({
     path: '/superset/all_entities/',
     Component: AllEntities,
