@@ -41,7 +41,7 @@ def superset() -> None:
 
     @app.shell_context_processor
     def make_shell_context() -> dict[str, Any]:
-        return dict(app=app, db=db)
+        return {"app": app, "db": db}
 
 
 # add sub-commands
@@ -71,12 +71,7 @@ def init() -> None:
 def version(verbose: bool) -> None:
     """Prints the current version number"""
     print(Fore.BLUE + "-=" * 15)
-    print(
-        Fore.YELLOW
-        + "Superset "
-        + Fore.CYAN
-        + "{version}".format(version=app.config["VERSION_STRING"])
-    )
+    print(Fore.YELLOW + "Superset " + Fore.CYAN + f"{app.config['VERSION_STRING']}")
     print(Fore.BLUE + "-=" * 15)
     if verbose:
         print("[DB] : " + f"{db.engine}")
