@@ -65,7 +65,6 @@ from sqlalchemy.orm import (
     reconstructor,
     relationship,
     RelationshipProperty,
-    Session,
 )
 from sqlalchemy.orm.mapper import Mapper
 from sqlalchemy.schema import UniqueConstraint
@@ -699,7 +698,7 @@ class BaseDatasource(
 
     @classmethod
     def get_datasource_by_name(
-        cls, session: Session, datasource_name: str, schema: str, database_name: str
+        cls, datasource_name: str, schema: str, database_name: str
     ) -> BaseDatasource | None:
         raise NotImplementedError()
 
@@ -757,7 +756,7 @@ class AnnotationDatasource(BaseDatasource):
         raise NotImplementedError()
 
 
-class TableColumn(Model, AuditMixinNullable, ImportExportMixin, CertificationMixin):
+class TableColumn(AuditMixinNullable, ImportExportMixin, CertificationMixin, Model):
 
     """ORM object for table columns, each table can have multiple columns"""
 
@@ -971,7 +970,7 @@ class TableColumn(Model, AuditMixinNullable, ImportExportMixin, CertificationMix
         return {s: getattr(self, s) for s in attrs if hasattr(self, s)}
 
 
-class SqlMetric(Model, AuditMixinNullable, ImportExportMixin, CertificationMixin):
+class SqlMetric(AuditMixinNullable, ImportExportMixin, CertificationMixin, Model):
 
     """ORM object for metrics, each table can have multiple metrics"""
 
@@ -1238,14 +1237,13 @@ class SqlaTable(
     @classmethod
     def get_datasource_by_name(
         cls,
-        session: Session,
         datasource_name: str,
         schema: str | None,
         database_name: str,
     ) -> SqlaTable | None:
         schema = schema or None
         query = (
-            session.query(cls)
+            db.session.query(cls)
             .join(Database)
             .filter(cls.table_name == datasource_name)
             .filter(Database.database_name == database_name)
@@ -1903,13 +1901,12 @@ class SqlaTable(
     @classmethod
     def query_datasources_by_name(
         cls,
-        session: Session,
         database: Database,
         datasource_name: str,
         schema: str | None = None,
     ) -> list[SqlaTable]:
         query = (
-            session.query(cls)
+            db.session.query(cls)
             .filter_by(database_id=database.id)
             .filter_by(table_name=datasource_name)
         )
@@ -1920,14 +1917,13 @@ class SqlaTable(
     @classmethod
     def query_datasources_by_permissions(  # pylint: disable=invalid-name
         cls,
-        session: Session,
         database: Database,
         permissions: set[str],
         schema_perms: set[str],
     ) -> list[SqlaTable]:
         # TODO(hughhhh): add unit test
         return (
-            session.query(cls)
+            db.session.query(cls)
             .filter_by(database_id=database.id)
             .filter(
                 or_(
@@ -1939,12 +1935,10 @@ class SqlaTable(
         )
 
     @classmethod
-    def get_eager_sqlatable_datasource(
-        cls, session: Session, datasource_id: int
-    ) -> SqlaTable:
+    def get_eager_sqlatable_datasource(cls, datasource_id: int) -> SqlaTable:
         """Returns SqlaTable with columns and metrics."""
         return (
-            session.query(cls)
+            db.session.query(cls)
             .options(
                 sa.orm.subqueryload(cls.columns),
                 sa.orm.subqueryload(cls.metrics),
@@ -1954,8 +1948,8 @@ class SqlaTable(
         )
 
     @classmethod
-    def get_all_datasources(cls, session: Session) -> list[SqlaTable]:
-        qry = session.query(cls)
+    def get_all_datasources(cls) -> list[SqlaTable]:
+        qry = db.session.query(cls)
         qry = cls.default_query(qry)
         return qry.all()
 
@@ -2037,8 +2031,7 @@ class SqlaTable(
         :param connection: Unused.
         :param target: The metric or column that was updated.
         """
-        inspector = inspect(target)
-        session = inspector.session
+        session = inspect(target).session  # pylint: disable=disallowed-name
 
         # Forces an update to the table's changed_on value when a metric or column on the
         # table is updated. This busts the cache key for all charts that use the table.
@@ -2072,7 +2065,7 @@ class SqlaTable(
         if self.database_id and (
             not self.database or self.database.id != self.database_id
         ):
-            session = inspect(self).session
+            session = inspect(self).session  # pylint: disable=disallowed-name
             self.database = session.query(Database).filter_by(id=self.database_id).one()
 
 
@@ -2123,4 +2116,4 @@ class RowLevelSecurityFilter(Model, AuditMixinNullable):
         secondary=RLSFilterTables,
         backref="row_level_security_filters",
     )
-    clause = Column(Text, nullable=False)
+    clause = Column(MediumText(), nullable=False)
