@@ -22,7 +22,6 @@ from datetime import datetime
 from typing import Any
 
 from sqlalchemy.exc import SQLAlchemyError
-from sqlalchemy.orm import Session
 
 from superset.daos.base import BaseDAO
 from superset.daos.exceptions import DAODeleteFailedError
@@ -204,27 +203,25 @@ class ReportScheduleDAO(BaseDAO[ReportSchedule]):
         return super().update(item, attributes, commit)
 
     @staticmethod
-    def find_active(session: Session | None = None) -> list[ReportSchedule]:
+    def find_active() -> list[ReportSchedule]:
         """
-        Find all active reports. If session is passed it will be used instead of the
-        default `db.session`, this is useful when on a celery worker session context
+        Find all active reports.
         """
-        session = session or db.session
         return (
-            session.query(ReportSchedule).filter(ReportSchedule.active.is_(True)).all()
+            db.session.query(ReportSchedule)
+            .filter(ReportSchedule.active.is_(True))
+            .all()
         )
 
     @staticmethod
     def find_last_success_log(
         report_schedule: ReportSchedule,
-        session: Session | None = None,
     ) -> ReportExecutionLog | None:
         """
         Finds last success execution log for a given report
         """
-        session = session or db.session
         return (
-            session.query(ReportExecutionLog)
+            db.session.query(ReportExecutionLog)
             .filter(
                 ReportExecutionLog.state == ReportState.SUCCESS,
                 ReportExecutionLog.report_schedule == report_schedule,
@@ -236,14 +233,12 @@ class ReportScheduleDAO(BaseDAO[ReportSchedule]):
     @staticmethod
     def find_last_entered_working_log(
         report_schedule: ReportSchedule,
-        session: Session | None = None,
     ) -> ReportExecutionLog | None:
         """
         Finds last success execution log for a given report
         """
-        session = session or db.session
         return (
-            session.query(ReportExecutionLog)
+            db.session.query(ReportExecutionLog)
             .filter(
                 ReportExecutionLog.state == ReportState.WORKING,
                 ReportExecutionLog.report_schedule == report_schedule,
@@ -256,14 +251,12 @@ class ReportScheduleDAO(BaseDAO[ReportSchedule]):
     @staticmethod
     def find_last_error_notification(
         report_schedule: ReportSchedule,
-        session: Session | None = None,
     ) -> ReportExecutionLog | None:
         """
         Finds last error email sent
         """
-        session = session or db.session
         last_error_email_log = (
-            session.query(ReportExecutionLog)
+            db.session.query(ReportExecutionLog)
             .filter(
                 ReportExecutionLog.error_message
                 == REPORT_SCHEDULE_ERROR_NOTIFICATION_MARKER,
@@ -276,7 +269,7 @@ class ReportScheduleDAO(BaseDAO[ReportSchedule]):
             return None
         # Checks that only errors have occurred since the last email
         report_from_last_email = (
-            session.query(ReportExecutionLog)
+            db.session.query(ReportExecutionLog)
             .filter(
                 ReportExecutionLog.state.notin_(
                     [ReportState.ERROR, ReportState.WORKING]
@@ -293,13 +286,11 @@ class ReportScheduleDAO(BaseDAO[ReportSchedule]):
     def bulk_delete_logs(
         model: ReportSchedule,
         from_date: datetime,
-        session: Session | None = None,
         commit: bool = True,
     ) -> int | None:
-        session = session or db.session
         try:
             row_count = (
-                session.query(ReportExecutionLog)
+                db.session.query(ReportExecutionLog)
                 .filter(
                     ReportExecutionLog.report_schedule == model,
                     ReportExecutionLog.end_dttm < from_date,
@@ -307,8 +298,8 @@ class ReportScheduleDAO(BaseDAO[ReportSchedule]):
                 .delete(synchronize_session="fetch")
             )
             if commit:
-                session.commit()
+                db.session.commit()
             return row_count
         except SQLAlchemyError as ex:
-            session.rollback()
+            db.session.rollback()
             raise DAODeleteFailedError(str(ex)) from ex
