@@ -19,10 +19,10 @@ import logging
 from flask import Response
 from flask_appbuilder.api import expose, protect, safe
 
-from superset.dashboards.filter_state.commands.create import CreateFilterStateCommand
-from superset.dashboards.filter_state.commands.delete import DeleteFilterStateCommand
-from superset.dashboards.filter_state.commands.get import GetFilterStateCommand
-from superset.dashboards.filter_state.commands.update import UpdateFilterStateCommand
+from superset.commands.dashboard.filter_state.create import CreateFilterStateCommand
+from superset.commands.dashboard.filter_state.delete import DeleteFilterStateCommand
+from superset.commands.dashboard.filter_state.get import GetFilterStateCommand
+from superset.commands.dashboard.filter_state.update import UpdateFilterStateCommand
 from superset.extensions import event_logger
 from superset.temporary_cache.api import TemporaryCacheRestApi
 
@@ -54,11 +54,10 @@ class DashboardFilterStateRestApi(TemporaryCacheRestApi):
         log_to_statsd=False,
     )
     def post(self, pk: int) -> Response:
-        """Stores a new value.
+        """Create a dashboard's filter state.
         ---
         post:
-          description: >-
-            Stores a new value.
+          summary: Create a dashboard's filter state
           parameters:
           - in: path
             schema:
@@ -104,11 +103,10 @@ class DashboardFilterStateRestApi(TemporaryCacheRestApi):
         log_to_statsd=False,
     )
     def put(self, pk: int, key: str) -> Response:
-        """Updates an existing value.
+        """Update a dashboard's filter state value.
         ---
         put:
-          description: >-
-            Updates an existing value.
+          summary: Update a dashboard's filter state value
           parameters:
           - in: path
             schema:
@@ -160,11 +158,10 @@ class DashboardFilterStateRestApi(TemporaryCacheRestApi):
         log_to_statsd=False,
     )
     def get(self, pk: int, key: str) -> Response:
-        """Retrives a value.
+        """Get a dashboard's filter state value.
         ---
         get:
-          description: >-
-            Retrives a value.
+          summary: Get a dashboard's filter state value
           parameters:
           - in: path
             schema:
@@ -206,11 +203,10 @@ class DashboardFilterStateRestApi(TemporaryCacheRestApi):
         log_to_statsd=False,
     )
     def delete(self, pk: int, key: str) -> Response:
-        """Deletes a value.
+        """Delete a dashboard's filter state value.
         ---
         delete:
-          description: >-
-            Deletes a value.
+          summary: Delete a dashboard's filter state value
           parameters:
           - in: path
             schema:
