@@ -153,7 +153,7 @@ def get_available_engine_specs() -> dict[type[BaseEngineSpec], set[str]]:
         try:
             dialect = ep.load()
         except Exception as ex:  # pylint: disable=broad-except
-            logger.warning("Unable to load SQLAlchemy dialect %s: %s", ep.name, ex)
+            logger.warning("Unable to load SQLAlchemy dialect %s: %s", dialect, ex)
         else:
             backend = dialect.name
             if isinstance(backend, bytes):
