@@ -63,10 +63,10 @@ def load_flights(only_metadata: bool = False, force: bool = False) -> None:
     tbl = db.session.query(table).filter_by(table_name=tbl_name).first()
     if not tbl:
         tbl = table(table_name=tbl_name, schema=schema)
+        db.session.add(tbl)
     tbl.description = "Random set of flights in the US"
     tbl.database = database
     tbl.filter_select_enabled = True
-    db.session.merge(tbl)
     db.session.commit()
     tbl.fetch_metadata()
     print("Done loading table!")
