@@ -103,7 +103,7 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         ),
         Slice(
             **slice_kwargs,
-            slice_name="Time-Series Line Chart",
+            slice_name="Line Chart",
             viz_type="echarts_timeseries_line",
             params=get_slice_json(
                 defaults,
@@ -114,7 +114,7 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         ),
         Slice(
             **slice_kwargs,
-            slice_name="Time-Series Area Chart",
+            slice_name="Area Chart",
             viz_type="echarts_area",
             params=get_slice_json(
                 defaults,
@@ -125,7 +125,7 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         ),
         Slice(
             **slice_kwargs,
-            slice_name="Time-Series Bar Chart V2",
+            slice_name="Bar Chart V2",
             viz_type="echarts_timeseries_bar",
             params=get_slice_json(
                 defaults,
@@ -136,7 +136,7 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         ),
         Slice(
             **slice_kwargs,
-            slice_name="Time-Series Scatter Chart",
+            slice_name="Scatter Chart",
             viz_type="echarts_timeseries_scatter",
             params=get_slice_json(
                 defaults,
@@ -238,7 +238,7 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         ),
         Slice(
             **slice_kwargs,
-            slice_name="Time-Series Percent Change Chart",
+            slice_name="Percent Change Chart",
             viz_type="compare",
             params=get_slice_json(
                 defaults,
@@ -249,7 +249,7 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         ),
         Slice(
             **slice_kwargs,
-            slice_name="Time-Series Generic Chart",
+            slice_name="Generic Chart",
             viz_type="echarts_timeseries",
             params=get_slice_json(
                 defaults,
@@ -260,7 +260,7 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         ),
         Slice(
             **slice_kwargs,
-            slice_name="Time-Series Smooth Line Chart",
+            slice_name="Smooth Line Chart",
             viz_type="echarts_timeseries_smooth",
             params=get_slice_json(
                 defaults,
@@ -271,7 +271,7 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         ),
         Slice(
             **slice_kwargs,
-            slice_name="Time-Series Step Line Chart",
+            slice_name="Step Line Chart",
             viz_type="echarts_timeseries_step",
             params=get_slice_json(
                 defaults,
@@ -317,10 +317,10 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         Slice(
             **slice_kwargs,
             slice_name="Line Chart",
-            viz_type="line",
+            viz_type="echarts_timeseries_line",
             params=get_slice_json(
                 defaults,
-                viz_type="line",
+                viz_type="echarts_timeseries_line",
                 metrics=["sum__num"],
                 groupby=["gender"],
             ),
@@ -397,12 +397,12 @@ def create_slices(tbl: SqlaTable) -> list[Slice]:
         Slice(
             **slice_kwargs,
             slice_name="Sunburst Chart",
-            viz_type="sunburst",
+            viz_type="sunburst_v2",
             params=get_slice_json(
                 defaults,
-                viz_type="sunburst",
+                viz_type="sunburst_v2",
                 metric="sum__num",
-                groupby=["gender", "state"],
+                columns=["gender", "state"],
             ),
         ),
         Slice(
@@ -545,7 +545,7 @@ def load_supported_charts_dashboard() -> None:
     "meta": {
       "chartId": 5,
       "height": 50,
-      "sliceName": "Time-Series Line Chart",
+      "sliceName": "Line Chart",
       "width": 4
     },
     "type": "CHART"
@@ -562,7 +562,7 @@ def load_supported_charts_dashboard() -> None:
     "meta": {
       "chartId": 6,
       "height": 50,
-      "sliceName": "Time-Series Bar Chart V2",
+      "sliceName": "Bar Chart V2",
       "width": 4
     },
     "type": "CHART"
@@ -579,7 +579,7 @@ def load_supported_charts_dashboard() -> None:
     "meta": {
       "chartId": 7,
       "height": 50,
-      "sliceName": "Time-Series Area Chart",
+      "sliceName": "Area Chart",
       "width": 4
     },
     "type": "CHART"
@@ -596,7 +596,7 @@ def load_supported_charts_dashboard() -> None:
     "meta": {
       "chartId": 8,
       "height": 50,
-      "sliceName": "Time-Series Scatter Chart",
+      "sliceName": "Scatter Chart",
       "width": 4
     },
     "type": "CHART"
@@ -732,7 +732,7 @@ def load_supported_charts_dashboard() -> None:
     "meta": {
       "chartId": 16,
       "height": 50,
-      "sliceName": "Time-Series Percent Change Chart",
+      "sliceName": "Percent Change Chart",
       "width": 4
     },
     "type": "CHART"
@@ -749,7 +749,7 @@ def load_supported_charts_dashboard() -> None:
     "meta": {
       "chartId": 17,
       "height": 50,
-      "sliceName": "Time-Series Generic Chart",
+      "sliceName": "Generic Chart",
       "width": 4
     },
     "type": "CHART"
@@ -766,7 +766,7 @@ def load_supported_charts_dashboard() -> None:
     "meta": {
       "chartId": 18,
       "height": 50,
-      "sliceName": "Time-Series Smooth Line Chart",
+      "sliceName": "Smooth Line Chart",
       "width": 4
     },
     "type": "CHART"
@@ -783,7 +783,7 @@ def load_supported_charts_dashboard() -> None:
     "meta": {
       "chartId": 19,
       "height": 50,
-      "sliceName": "Time-Series Step Line Chart",
+      "sliceName": "Step Line Chart",
       "width": 4
     },
     "type": "CHART"
