@@ -16,10 +16,11 @@
 # under the License.
 
 openapi_spec_methods_override = {
-    "get": {"get": {"description": "Get a report schedule log"}},
+    "get": {"get": {"summary": "Get a report schedule log"}},
     "get_list": {
         "get": {
-            "description": "Get a list of report schedule logs, use Rison or JSON "
+            "summary": "Get a list of report schedule logs",
+            "description": "Gets a list of report schedule logs, use Rison or JSON "
             "query parameters for filtering, sorting,"
             " pagination and for selecting specific"
             " columns and metadata.",
