@@ -31,7 +31,7 @@ from jinja2 import nodes
 from sqlalchemy import and_
 from sqlglot import exp, parse, parse_one
 from sqlglot.dialects import Dialects
-from sqlglot.errors import ParseError, SqlglotError
+from sqlglot.errors import SqlglotError
 from sqlglot.optimizer.scope import Scope, ScopeType, traverse_scope
 from sqlparse import keywords
 from sqlparse.lexer import Lexer
@@ -297,21 +297,11 @@ class ParsedQuery:
             statements = parse(self.stripped(), dialect=self._dialect)
         except SqlglotError as ex:
             logger.warning("Unable to parse SQL (%s): %s", self._dialect, self.sql)
-
-            message = (
-                "Error parsing near '{highlight}' at line {line}:{col}".format(  # pylint: disable=consider-using-f-string
-                    **ex.errors[0]
-                )
-                if isinstance(ex, ParseError)
-                else str(ex)
-            )
-
+            dialect = self._dialect or "generic"
             raise SupersetSecurityException(
                 SupersetError(
                     error_type=SupersetErrorType.QUERY_SECURITY_ACCESS_ERROR,
-                    message=__(
-                        f"You may have an error in your SQL statement. {message}"
-                    ),
+                    message=__(f"Unable to parse SQL ({dialect}): {self.sql}"),
                     level=ErrorLevel.ERROR,
                 )
             ) from ex
@@ -1099,19 +1089,16 @@ def extract_tables_from_jinja_sql(sql: str, database: Database) -> set[Table]:
             "latest_partition",
             "latest_sub_partition",
         ):
-            # Try to extract the table referenced in the macro.
-            try:
-                tables.add(
-                    Table(
-                        *[
-                            remove_quotes(part.strip())
-                            for part in node.args[0].as_const().split(".")[::-1]
-                            if len(node.args) == 1
-                        ]
-                    )
+            # Extract the table referenced in the macro.
+            tables.add(
+                Table(
+                    *[
+                        remove_quotes(part)
+                        for part in node.args[0].value.split(".")[::-1]
+                        if len(node.args) == 1
+                    ]
                 )
-            except nodes.Impossible:
-                pass
+            )
 
             # Replace the potentially problematic Jinja macro with some benign SQL.
             node.__class__ = nodes.TemplateData
