@@ -32,6 +32,7 @@ from superset.models.slice import Slice
 from superset.tags.models import Tag, TaggedObject
 from superset.utils.date_parser import parse_human_datetime
 from superset.utils.machine_auth import MachineAuthProvider
+from superset.utils.urls import get_url_path
 
 logger = get_task_logger(__name__)
 logger.setLevel(logging.INFO)
@@ -94,14 +95,7 @@ class DummyStrategy(Strategy):  # pylint: disable=too-few-public-methods
     name = "dummy"
 
     def get_payloads(self) -> list[dict[str, int]]:
-        session = db.create_scoped_session()
-
-        try:
-            charts = session.query(Slice).all()
-        finally:
-            session.close()
-
-        return [get_payload(chart) for chart in charts]
+        return [get_payload(chart) for chart in db.session.query(Slice).all()]
 
 
 class TopNDashboardsStrategy(Strategy):  # pylint: disable=too-few-public-methods
@@ -130,28 +124,24 @@ class TopNDashboardsStrategy(Strategy):  # pylint: disable=too-few-public-method
         self.since = parse_human_datetime(since) if since else None
 
     def get_payloads(self) -> list[dict[str, int]]:
-        payloads = []
-        session = db.create_scoped_session()
+        records = (
+            db.session.query(Log.dashboard_id, func.count(Log.dashboard_id))
+            .filter(and_(Log.dashboard_id.isnot(None), Log.dttm >= self.since))
+            .group_by(Log.dashboard_id)
+            .order_by(func.count(Log.dashboard_id).desc())
+            .limit(self.top_n)
+            .all()
+        )
+        dash_ids = [record.dashboard_id for record in records]
+        dashboards = (
+            db.session.query(Dashboard).filter(Dashboard.id.in_(dash_ids)).all()
+        )
 
-        try:
-            records = (
-                session.query(Log.dashboard_id, func.count(Log.dashboard_id))
-                .filter(and_(Log.dashboard_id.isnot(None), Log.dttm >= self.since))
-                .group_by(Log.dashboard_id)
-                .order_by(func.count(Log.dashboard_id).desc())
-                .limit(self.top_n)
-                .all()
-            )
-            dash_ids = [record.dashboard_id for record in records]
-            dashboards = (
-                session.query(Dashboard).filter(Dashboard.id.in_(dash_ids)).all()
-            )
-            for dashboard in dashboards:
-                for chart in dashboard.slices:
-                    payloads.append(get_payload(chart, dashboard))
-        finally:
-            session.close()
-        return payloads
+        return [
+            get_payload(chart, dashboard)
+            for dashboard in dashboards
+            for chart in dashboard.slices
+        ]
 
 
 class DashboardTagsStrategy(Strategy):  # pylint: disable=too-few-public-methods
@@ -178,48 +168,44 @@ class DashboardTagsStrategy(Strategy):  # pylint: disable=too-few-public-methods
 
     def get_payloads(self) -> list[dict[str, int]]:
         payloads = []
-        session = db.create_scoped_session()
+        tags = db.session.query(Tag).filter(Tag.name.in_(self.tags)).all()
+        tag_ids = [tag.id for tag in tags]
 
-        try:
-            tags = session.query(Tag).filter(Tag.name.in_(self.tags)).all()
-            tag_ids = [tag.id for tag in tags]
-
-            # add dashboards that are tagged
-            tagged_objects = (
-                session.query(TaggedObject)
-                .filter(
-                    and_(
-                        TaggedObject.object_type == "dashboard",
-                        TaggedObject.tag_id.in_(tag_ids),
-                    )
+        # add dashboards that are tagged
+        tagged_objects = (
+            db.session.query(TaggedObject)
+            .filter(
+                and_(
+                    TaggedObject.object_type == "dashboard",
+                    TaggedObject.tag_id.in_(tag_ids),
                 )
-                .all()
             )
-            dash_ids = [tagged_object.object_id for tagged_object in tagged_objects]
-            tagged_dashboards = session.query(Dashboard).filter(
-                Dashboard.id.in_(dash_ids)
-            )
-            for dashboard in tagged_dashboards:
-                for chart in dashboard.slices:
-                    payloads.append(get_payload(chart))
-
-            # add charts that are tagged
-            tagged_objects = (
-                session.query(TaggedObject)
-                .filter(
-                    and_(
-                        TaggedObject.object_type == "chart",
-                        TaggedObject.tag_id.in_(tag_ids),
-                    )
-                )
-                .all()
-            )
-            chart_ids = [tagged_object.object_id for tagged_object in tagged_objects]
-            tagged_charts = session.query(Slice).filter(Slice.id.in_(chart_ids))
-            for chart in tagged_charts:
+            .all()
+        )
+        dash_ids = [tagged_object.object_id for tagged_object in tagged_objects]
+        tagged_dashboards = db.session.query(Dashboard).filter(
+            Dashboard.id.in_(dash_ids)
+        )
+        for dashboard in tagged_dashboards:
+            for chart in dashboard.slices:
                 payloads.append(get_payload(chart))
-        finally:
-            session.close()
+
+        # add charts that are tagged
+        tagged_objects = (
+            db.session.query(TaggedObject)
+            .filter(
+                and_(
+                    TaggedObject.object_type == "chart",
+                    TaggedObject.tag_id.in_(tag_ids),
+                )
+            )
+            .all()
+        )
+        chart_ids = [tagged_object.object_id for tagged_object in tagged_objects]
+        tagged_charts = db.session.query(Slice).filter(Slice.id.in_(chart_ids))
+        for chart in tagged_charts:
+            payloads.append(get_payload(chart))
+
         return payloads
 
 
@@ -233,8 +219,7 @@ def fetch_url(data: str, headers: dict[str, str]) -> dict[str, str]:
     """
     result = {}
     try:
-        baseurl = app.config["WEBDRIVER_BASEURL"]
-        url = f"{baseurl}api/v1/chart/warm_up_cache"
+        url = get_url_path("Superset.warm_up_cache")
         logger.info("Fetching %s with payload %s", url, data)
         req = request.Request(
             url, data=bytes(data, "utf-8"), headers=headers, method="PUT"
