@@ -50,7 +50,9 @@ class SQLAlchemyUtilsAdapter(  # pylint: disable=too-few-public-methods
         if app_config:
             return EncryptedType(*args, app_config["SECRET_KEY"], **kwargs)
 
-        raise Exception("Missing app_config kwarg")
+        raise Exception(  # pylint: disable=broad-exception-raised
+            "Missing app_config kwarg"
+        )
 
 
 class EncryptedFieldFactory:
@@ -70,7 +72,9 @@ class EncryptedFieldFactory:
         if self._concrete_type_adapter:
             return self._concrete_type_adapter.create(self._config, *args, **kwargs)
 
-        raise Exception("App not initialized yet. Please call init_app first")
+        raise Exception(  # pylint: disable=broad-exception-raised
+            "App not initialized yet. Please call init_app first"
+        )
 
 
 class SecretsMigrator:
@@ -146,7 +150,7 @@ class SecretsMigrator:
                 unencrypted_value = previous_encrypted_type.process_result_value(
                     self._read_bytes(column_name, row[column_name]), self._dialect
                 )
-            except ValueError as exc:
+            except ValueError as ex:
                 # Failed to unencrypt
                 try:
                     encrypted_type.process_result_value(
@@ -160,7 +164,7 @@ class SecretsMigrator:
                     )
                     return
                 except Exception:
-                    raise Exception from exc
+                    raise Exception from ex  # pylint: disable=broad-exception-raised
 
             re_encrypted_columns[column_name] = encrypted_type.process_bind_param(
                 unencrypted_value,
