@@ -167,7 +167,6 @@ class CsvToDatabaseView(CustomFormView):
         form.overwrite_duplicate.data = True
         form.skip_initial_space.data = False
         form.skip_blank_lines.data = True
-        form.infer_datetime_format.data = True
         form.day_first.data = False
         form.decimal.data = "."
         form.if_exists.data = "fail"
@@ -199,11 +198,9 @@ class CsvToDatabaseView(CustomFormView):
                     filepath_or_buffer=form.csv_file.data,
                     header=form.header.data if form.header.data else 0,
                     index_col=form.index_col.data,
-                    infer_datetime_format=form.infer_datetime_format.data,
                     dayfirst=form.day_first.data,
                     iterator=True,
                     keep_default_na=not form.null_values.data,
-                    mangle_dupe_cols=form.overwrite_duplicate.data,
                     usecols=form.use_cols.data if form.use_cols.data else None,
                     na_values=form.null_values.data if form.null_values.data else None,
                     nrows=form.nrows.data,
@@ -310,7 +307,6 @@ class ExcelToDatabaseView(SimpleFormView):
 
     def form_get(self, form: ExcelToDatabaseForm) -> None:
         form.header.data = 0
-        form.mangle_dupe_cols.data = True
         form.decimal.data = "."
         form.if_exists.data = "fail"
         form.sheet_name.data = ""
@@ -346,8 +342,7 @@ class ExcelToDatabaseView(SimpleFormView):
                 index_col=form.index_col.data,
                 io=form.excel_file.data,
                 keep_default_na=not form.null_values.data,
-                mangle_dupe_cols=form.mangle_dupe_cols.data,
-                na_values=form.null_values.data if form.null_values.data else None,
+                na_values=form.null_values.data if form.null_values.data else [],
                 parse_dates=form.parse_dates.data,
                 skiprows=form.skiprows.data,
                 sheet_name=form.sheet_name.data if form.sheet_name.data else 0,
@@ -459,9 +454,10 @@ class ColumnarToDatabaseView(SimpleFormView):
         if file_type == {"zip"}:
             zipfile_ob = zipfile.ZipFile(  # pylint: disable=consider-using-with
                 form.columnar_file.data[0]
-            )  # pylint: disable=consider-using-with
+            )
             file_type = {filename.split(".")[-1] for filename in zipfile_ob.namelist()}
             files = [
+                # pylint: disable=consider-using-with
                 io.BytesIO((zipfile_ob.open(filename).read(), filename)[0])
                 for filename in zipfile_ob.namelist()
             ]
