@@ -15,22 +15,15 @@
 # specific language governing permissions and limitations
 # under the License.
 from superset import app, talisman
+from superset.stats_logger import BaseStatsLogger
 from superset.superset_typing import FlaskResponse
 
 
-@talisman(force_https=False)
-@app.route("/ping")
-def ping() -> FlaskResponse:
-    return "OK"
-
-
-@talisman(force_https=False)
-@app.route("/healthcheck")
-def healthcheck() -> FlaskResponse:
-    return "OK"
-
-
 @talisman(force_https=False)
 @app.route("/health")
+@app.route("/healthcheck")
+@app.route("/ping")
 def health() -> FlaskResponse:
+    stats_logger: BaseStatsLogger = app.config["STATS_LOGGER"]
+    stats_logger.incr("health")
     return "OK"
