@@ -187,25 +187,20 @@ class SupersetTestCase(TestCase):
         except ImportError:
             return False
 
-    def get_or_create(self, cls, criteria, session, **kwargs):
-        obj = session.query(cls).filter_by(**criteria).first()
+    def get_or_create(self, cls, criteria, **kwargs):
+        obj = db.session.query(cls).filter_by(**criteria).first()
         if not obj:
             obj = cls(**criteria)
         obj.__dict__.update(**kwargs)
-        session.add(obj)
-        session.commit()
+        db.session.add(obj)
+        db.session.commit()
         return obj
 
     def login(self, username="admin", password="general"):
         return login(self.client, username, password)
 
-    def get_slice(
-        self, slice_name: str, session: Session, expunge_from_session: bool = True
-    ) -> Slice:
-        slc = session.query(Slice).filter_by(slice_name=slice_name).one()
-        if expunge_from_session:
-            session.expunge_all()
-        return slc
+    def get_slice(self, slice_name: str) -> Slice:
+        return db.session.query(Slice).filter_by(slice_name=slice_name).one()
 
     @staticmethod
     def get_table(
@@ -353,7 +348,6 @@ class SupersetTestCase(TestCase):
         return self.get_or_create(
             cls=models.Database,
             criteria={"database_name": database_name},
-            session=db.session,
             sqlalchemy_uri="sqlite:///:memory:",
             id=db_id,
             extra=extra,
@@ -375,7 +369,6 @@ class SupersetTestCase(TestCase):
         database = self.get_or_create(
             cls=models.Database,
             criteria={"database_name": database_name},
-            session=db.session,
             sqlalchemy_uri="db_for_macros_testing://user@host:8080/hive",
             id=db_id,
         )
@@ -398,8 +391,7 @@ class SupersetTestCase(TestCase):
             db.session.commit()
 
     def get_dash_by_slug(self, dash_slug):
-        sesh = db.session()
-        return sesh.query(Dashboard).filter_by(slug=dash_slug).first()
+        return db.session.query(Dashboard).filter_by(slug=dash_slug).first()
 
     def get_assert_metric(self, uri: str, func_name: str) -> Response:
         """
@@ -522,11 +514,10 @@ class SupersetTestCase(TestCase):
 @contextmanager
 def db_insert_temp_object(obj: DeclarativeMeta):
     """Insert a temporary object in database; delete when done."""
-    session = db.session
     try:
-        session.add(obj)
-        session.commit()
+        db.session.add(obj)
+        db.session.commit()
         yield obj
     finally:
-        session.delete(obj)
-        session.commit()
+        db.session.delete(obj)
+        db.session.commit()
