@@ -17,6 +17,7 @@
 import pytest
 
 from superset.utils.core import form_data_to_adhoc, simple_filter_to_adhoc
+from tests.integration_tests.test_app import app
 
 
 def test_simple_filter_to_adhoc_generates_deterministic_values():
@@ -81,4 +82,5 @@ def test_form_data_to_adhoc_incorrect_clause_type():
     form_data = {"where": "1 = 1", "having": "count(*) > 1"}
 
     with pytest.raises(ValueError):
-        form_data_to_adhoc(form_data, "foobar")
+        with app.app_context():
+            form_data_to_adhoc(form_data, "foobar")
