@@ -273,30 +273,26 @@ def test_extract_tables_illdefined() -> None:
     with pytest.raises(SupersetSecurityException) as excinfo:
         extract_tables("SELECT * FROM schemaname.")
     assert (
-        str(excinfo.value)
-        == "You may have an error in your SQL statement. Error parsing near '.' at line 1:25"
+        str(excinfo.value) == "Unable to parse SQL (generic): SELECT * FROM schemaname."
     )
 
     with pytest.raises(SupersetSecurityException) as excinfo:
         extract_tables("SELECT * FROM catalogname.schemaname.")
     assert (
         str(excinfo.value)
-        == "You may have an error in your SQL statement. Error parsing near '.' at line 1:37"
+        == "Unable to parse SQL (generic): SELECT * FROM catalogname.schemaname."
     )
 
     with pytest.raises(SupersetSecurityException) as excinfo:
         extract_tables("SELECT * FROM catalogname..")
     assert (
         str(excinfo.value)
-        == "You may have an error in your SQL statement. Error parsing near '.' at line 1:27"
+        == "Unable to parse SQL (generic): SELECT * FROM catalogname.."
     )
 
     with pytest.raises(SupersetSecurityException) as excinfo:
         extract_tables('SELECT * FROM "tbname')
-    assert (
-        str(excinfo.value)
-        == "You may have an error in your SQL statement. Error tokenizing 'SELECT * FROM \"tbnam'"
-    )
+    assert str(excinfo.value) == 'Unable to parse SQL (generic): SELECT * FROM "tbname'
 
     # odd edge case that works
     assert extract_tables("SELECT * FROM catalogname..tbname") == {
@@ -1794,8 +1790,7 @@ def test_get_rls_for_table(mocker: MockerFixture) -> None:
     Tests for ``get_rls_for_table``.
     """
     candidate = Identifier([Token(Name, "some_table")])
-    db = mocker.patch("superset.db")
-    dataset = db.session.query().filter().one_or_none()
+    dataset = mocker.patch("superset.db").session.query().filter().one_or_none()
     dataset.__str__.return_value = "some_table"
 
     dataset.get_sqla_row_level_filters.return_value = [text("organization_id = 1")]
@@ -1892,40 +1887,34 @@ SELECT * FROM t"""
     ],
 )
 @pytest.mark.parametrize(
-    "macro,expected",
+    "macro",
+    [
+        "latest_partition('foo.bar')",
+        "latest_sub_partition('foo.bar', baz='qux')",
+    ],
+)
+@pytest.mark.parametrize(
+    "sql,expected",
     [
         (
-            "latest_partition('foo.bar')",
+            "SELECT '{{{{ {engine}.{macro} }}}}'",
             {Table(table="bar", schema="foo")},
         ),
         (
-            "latest_partition(' foo.bar ')",  # Non-atypical user error which works
-            {Table(table="bar", schema="foo")},
-        ),
-        (
-            "latest_partition('foo.%s'|format('bar'))",
-            {Table(table="bar", schema="foo")},
-        ),
-        (
-            "latest_sub_partition('foo.bar', baz='qux')",
-            {Table(table="bar", schema="foo")},
-        ),
-        (
-            "latest_partition('foo.%s'|format(str('bar')))",
-            set(),
-        ),
-        (
-            "latest_partition('foo.{}'.format('bar'))",
-            set(),
+            "SELECT * FROM foo.baz WHERE quux = '{{{{ {engine}.{macro} }}}}'",
+            {Table(table="bar", schema="foo"), Table(table="baz", schema="foo")},
         ),
     ],
 )
 def test_extract_tables_from_jinja_sql(
-    engine: str, macro: str, expected: set[Table]
+    engine: str,
+    macro: str,
+    sql: str,
+    expected: set[Table],
 ) -> None:
     assert (
         extract_tables_from_jinja_sql(
-            sql=f"'{{{{ {engine}.{macro} }}}}'",
+            sql=sql.format(engine=engine, macro=macro),
             database=Mock(),
         )
         == expected
